@@ -70,14 +70,7 @@
 #' data3<-rpkb(size, c(0,0,1),rho,method="rejvmf")
 #' dat<-rbind(data1$x,data2$x, data3$x)
 #'
-#' #The following code can be used for plotting
-#' \donttest{
-#' library("rgl")
-#' plot3d(dat,col = groups, size=4,xlab = "", ylab = "",zlab = "")
-#' legend3d("right", legend = c("Class 1", "Class 2", "Class 3"), 
-#'             col = 1:3, pch = 20)
-#' }
-#' #Perform the clustering algorithm with number od clusters k=3.
+#' #Perform the clustering algorithm with number of clusters k=3.
 #' pkbd<- pkbc(dat, 3)
 #'
 #' @srrstats {G2.0a} Documentation of input nClust
@@ -108,6 +101,10 @@ setGeneric("pkbc",function(dat,
 #' @srrstats {UL2.3} inputs are all checked
 #' @srrstats {UL7.0} error messages are inserted for inappropriate inputs
 #' 
+#' @importFrom methods new
+#' @importFrom stats uniroot
+#' 
+#' 
 #' @export
 setMethod("pkbc", signature(dat = "ANY"),
     function(dat,
@@ -418,10 +415,10 @@ setMethod("show", "pkbc", function(object) {
 #' 
 #' @param object Object of class \code{pkbc}
 #' 
-#' @return Display the logLikelihood values and within cluster sum of squares (wcss)
-#'         for all the values of number of clusters provided. For each of these value 
-#'         the estimated mixing proportions are showed together with a table with the 
-#'         assigned memberships.
+#' @return Display the logLikelihood values and within cluster sum of squares 
+#'         (wcss) for all the values of number of clusters provided. For each of
+#'         these values the estimated mixing proportions are showed together 
+#'         with a table with the assigned memberships.
 #' 
 #' @examples
 #' dat <- rbind(matrix(rnorm(100),2),matrix(rnorm(100,5),2))
@@ -485,8 +482,8 @@ setGeneric("stats_clusters",function(object,...){
 #' 
 #' Descriptive statistics for the identified clusters
 #'
-#' Method for objects of class \code{pkbc} which computes some 
-#' descriptive for each variable with respect to the detected groups. 
+#' Method for objects of class \code{pkbc} which computes descriptive 
+#' statistics for each variable with respect to the detected groups. 
 #'
 #' @param object Object of class \code{pkbc}.
 #' @param k Number of clusters to be used.
@@ -512,6 +509,11 @@ setGeneric("stats_clusters",function(object,...){
 #' @srrstats {UL3.2} true label can be provided as a separate input
 #' @srrstats {UL3.4} the function computes summary statistics with respect to 
 #'                   the identified clusters.
+#'                   
+#' @importFrom stats sd
+#' @importFrom stats median
+#' @importFrom stats IQR 
+#' 
 #' @rdname stats_clusters                  
 #' @export
 setMethod("stats_clusters", "pkbc", function(object, k){
@@ -653,7 +655,12 @@ repeat {
 #' the \code{PcaLocantore} function (package \code{rrcov}) are returned if 
 #' pca_res=TRUE.
 #' 
-#' @import rgl
+#' @importFrom rgl plot3d
+#' @importFrom rgl layout3d
+#' @importFrom rgl title3d
+#' @importFrom rgl next3d
+#' @importFrom rgl rgl.spheres
+#' @importFrom rgl open3d
 #' @import ggplot2
 #' @importFrom grDevices colorRampPalette
 #' @importFrom rrcov PcaLocantore
@@ -756,7 +763,7 @@ scatterplotMethod <- function(object, k, true_label=NULL, pca_res=FALSE) {
 #'         cosine similarity.
 #' 
 #' @import ggplot2
-#' @import ggpubr
+#' @importFrom ggpubr ggarrange
 #' 
 #' @srrstats {G1.4} roxigen2 is used
 #' 
@@ -926,11 +933,12 @@ setMethod("predict", signature(object="pkbc"),
 #' Mathematics, 20, 53–65.
 #'
 #' @importFrom mclust adjustedRandIndex
-#' @import clusterRepro
+#' @importFrom clusterRepro IGP.clusterRepro
 #' @importFrom cluster silhouette
+#' @importFrom stats dist
 #'
 #' @examples
-#' #We generate three sample of 100 observations from 3-dimensional
+#' #We generate three samples of 100 observations from 3-dimensional
 #' #Poisson kernel-based densities with rho=0.8 and different mean directions
 #' \donttest{
 #' size<-20
@@ -981,7 +989,7 @@ pkbc_validation <- function(object, true_label=NULL, h=1.5){
       # Compute the In-Group Proportion
       if(k>1){
          igp_k[[k]] <- IGP.clusterRepro(as.data.frame(t(x)), 
-                                        as.data.frame(t(object@res_k[[k]]$params$mu)))$IGP
+                              as.data.frame(t(object@res_k[[k]]$params$mu)))$IGP
       }
       # Compute the k-sample test
       #y_k <- as.numeric(object@res_k[[k]]$finalMemb)
@@ -1046,3 +1054,8 @@ pkbc_validation <- function(object, true_label=NULL, h=1.5){
    
    return(results)
 }
+.onLoad <- function(libname, pkgname) {
+   if (Sys.getenv("RGL_USE_NULL") == "") {
+      Sys.setenv(RGL_USE_NULL = "TRUE")
+   }
+}
\ No newline at end of file
