@@ -161,7 +161,7 @@ setMethod("show", "pk.test",
 #'                         uniform distribution.
 #' }
 #'
-#' @import ggpubr
+#' @importFrom ggpubr ggarrange
 #' @import ggplot2
 #' 
 #' @examples
@@ -172,6 +172,12 @@ setMethod("show", "pk.test",
 #' 
 #' @srrstats {G1.4} roxigen2 is used
 #' 
+#' @importFrom ggpp geom_table_npc
+#' @importFrom stats IQR
+#' @importFrom stats median
+#' @importFrom stats sd
+#' @importFrom stats runif
+#' 
 #' @export
 #'
 setMethod("summary", "pk.test", function(object) {
@@ -209,9 +215,13 @@ setMethod("summary", "pk.test", function(object) {
       stats[[i]] <- stats_step
       
       pl_stat <- ggplot() +
-         ggpp::annotate('table', x = 0.5, y = 0.5, 
-                     label = data.frame(Stat = rownames(stats_step),stats_step),
-                     hjust = 0.5, vjust = 0.5) +
+      geom_table_npc(data = data.frame(Stat = rownames(stats_step), stats_step),
+                     aes(npcx = 0.5, npcy = 0.5, 
+            label = list(data.frame(Stat = rownames(stats_step), stats_step))),
+                        hjust = 0.5, vjust = 0.5) +
+        #annotate('table', x = 0.5, y = 0.5, 
+                 #   label = data.frame(Stat = rownames(stats_step),stats_step),
+                    # hjust = 0.5, vjust = 0.5) +
          theme_void() +
          ggtitle("")+
          scale_color_brewer(palette='Set1')
