@@ -4,6 +4,9 @@
 #  #'
 #  #' @srrstats {G1.5} two-sample test example in the associated paper
 
+## ----setup, include=FALSE-----------------------------------------------------
+knitr::opts_chunk$set(warning = FALSE, message = FALSE) 
+
 ## ----message=FALSE------------------------------------------------------------
 library(sn)
 library(mvtnorm)
@@ -19,6 +22,7 @@ y_2 <- rmsn(n=n, xi=0, Omega = diag(d), alpha=rep(skewness_y,d))
 h <- 2
 set.seed(2468)
 two_test <- kb.test(x=x_2, y=y_2, h=h)
+two_test
 
 ## ----fig.width=6, fig.height=8------------------------------------------------
 summary_two <- summary(two_test)
