@@ -4,6 +4,7 @@
 #include <cmath>
 #include <map>
 #include <vector>
+#include <Eigen/Dense>
 using namespace Eigen;
 using namespace Rcpp;
 using namespace std;
@@ -170,13 +171,13 @@ Eigen::VectorXd kbNormTest(Eigen::MatrixXd x_mat, double h,
    k_center = ParamCentering( kmat_zz,  x_mat, H, mu_mat, Sigma_hat);
    
    // Compute the normality test V-statistic
-   double Vn = k_center.sum() /(n_x * (n_x));
+   double Vn = k_center.sum() /(n_x);
    // Compute the normality test U-statistic
    double Un = (k_center.sum() - k_center.diagonal().sum()) /(n_x * (n_x - 1));
    
    Eigen::VectorXd results(2);
-   results(0) = n_x * Un;
-   results(1) = n_x * Vn;
+   results(0) = Un;
+   results(1) = Vn;
    
    return results;
    
@@ -262,26 +263,9 @@ Eigen::VectorXd var_two(const Eigen::MatrixXd& Kcen,
  double est_var_Tr = 2 * n_factor * n_factor * pow(K_xx.array(),2).sum() +
     2 * m_factor * m_factor * pow(K_yy.array(),2).sum();
  
- double delta1 = 0.0;
- for (int i = 0; i < n; ++i) {
-    for (int j = 0; j < n; ++j) {
-       if (i != j) {  
-          for (int l = 0; l < m; ++l) {
-             delta1 += K_xx(i, j) * K_xy(i, l);
-          }
-       }
-    }
- }
- double delta2 = 0.0;
- for (int i = 0; i < m; ++i) {
-    for (int j = 0; j < m; ++j) {
-       if (i != j) {  
-          for (int l = 0; l < n; ++l) {
-             delta2 += K_yy(i, j) * K_xy(l, i);
-          }
-       }
-    }
- }
+ double delta1 =  (K_xx.transpose() * K_xy).sum();
+
+ double delta2 =  (K_yy.transpose() * K_xy.transpose()).sum();
 
  est_varD -= 8 * n_factor * cross_factor * delta1;
  est_varD -= 8 * m_factor * cross_factor * delta2;
@@ -380,8 +364,7 @@ Eigen::VectorXd stat2sample(Eigen::MatrixXd& x_mat, Eigen::MatrixXd& y_mat, doub
 //' 
 //' @keywords internal
 // [[Rcpp::export]]
-Eigen::VectorXd var_k(const Eigen::MatrixXd& Kcen, const Eigen::VectorXd& sizes,
-                      const Eigen::VectorXd& cum_size) 
+Eigen::VectorXd var_k(const Eigen::MatrixXd& Kcen, const Eigen::VectorXd& sizes, const Eigen::VectorXd& cum_size) 
 {
    int n = Kcen.rows();
    int K = sizes.size();
@@ -392,38 +375,31 @@ Eigen::VectorXd var_k(const Eigen::MatrixXd& Kcen, const Eigen::VectorXd& sizes,
    double C1 = 0.0;
    double C2 = 0.0;
    double C3 = 0.0;
+   
+   // Precompute factors
+   Eigen::VectorXd ni_factors = sizes.array().inverse() * (sizes.array() - 1).inverse();
+   Eigen::MatrixXd K_ll, K_lr, K_rr;
+   
    for (int l = 1; l <= K; ++l) {
+      double ni_factor = ni_factors[l - 1];
+      K_ll = Kcen_copy.block(cum_size[l - 1], cum_size[l - 1], sizes[l - 1], sizes[l - 1]);
       
-      double ni_factor = 1.0 / (sizes[l-1] * (sizes[l-1] - 1));
-      Eigen::MatrixXd K_ll = Kcen_copy.block(cum_size[l - 1], cum_size[l - 1], sizes[l - 1], sizes[l - 1]);
+      C1 += 2 * ni_factor * ni_factor * K_ll.array().square().sum();
       
-      C1 += 2 * ni_factor * ni_factor * pow(K_ll.array(),2).sum();
-      
-      for (int r = 1; r <= K; ++r) {
+      for (int r = l+1; r <= K; ++r) {
+         double n_lr_factor = 1.0 / (sizes[l - 1] * sizes[r - 1]);
+         K_lr = Kcen_copy.block(cum_size[l - 1], cum_size[r - 1], sizes[l - 1], sizes[r - 1]);
+         K_rr = Kcen_copy.block(cum_size[r - 1], cum_size[r - 1], sizes[r - 1], sizes[r - 1]);
          
-         double n_lr_factor = 1.0 / (sizes[l-1] * sizes[r-1]);
-         Eigen::MatrixXd K_lr = Kcen_copy.block(cum_size[l - 1], cum_size[r - 1], sizes[l - 1], sizes[r - 1]);
+         C2 += 8 * n_lr_factor * n_lr_factor * K_lr.array().square().sum();
+         
+         C3 -= 8 * n_lr_factor * ni_factor * (K_ll.transpose() * K_lr).sum();
+         C3 -= 8 * n_lr_factor * ni_factor * (K_rr.transpose() * K_lr.transpose()).sum();
          
-         if (r != l) 
-         {
-            for (int i = 0; i < sizes[l-1]; ++i) {
-               for (int j = 0; j < sizes[l-1]; ++j) {
-                  if (i != j) {
-                     for (int s = 0; s < sizes[r-1]; ++s){
-                        C3 -= 8 * n_lr_factor * ni_factor * K_ll(i, j) * K_lr(i, s); 
-                     }
-                  }
-               }
-            }
-         } 
-         if (r > l)
-         {
-            C2 += 8 * n_lr_factor * n_lr_factor * pow(K_lr.array(),2).sum();
-         }
       }
    }
-
-   double est_varD = pow(K-1,2) * C1 + C2 + C3;
+   
+   double est_varD = pow(K - 1, 2) * C1 + C2 + C3;
    double est_var_Tr = C1;
    
    Eigen::VectorXd results(2);
